## Cad Tickers

Set of utilities modules designed to scrap data from the web.

Will write more documentation later, for now refer to test cases.


For the tsx searching, it was kinda tedious to test each of the possible values, as a result, only `exchanges` and `marketcap` values are validated.

Given the new redesign of the web.tmxmoney site, don't expect the existing api to work
for a super long period of time.

Support will be provided to the best of my ability.

### How to run tests

```
pytest
```

#### Todo

* add just read the docs
